@@ -47,7 +47,44 @@ class AddHeader(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-ses-actions.AddHeader",
 ):
-    '''Adds a header to the received email.'''
+    '''Adds a header to the received email.
+
+    :exampleMetadata: infused
+
+    Example::
+
+        import aws_cdk.aws_s3 as s3
+        import aws_cdk.aws_ses_actions as actions
+        
+        
+        bucket = s3.Bucket(self, "Bucket")
+        topic = sns.Topic(self, "Topic")
+        
+        ses.ReceiptRuleSet(self, "RuleSet",
+            rules=[ses.ReceiptRuleOptions(
+                recipients=["hello@aws.com"],
+                actions=[
+                    actions.AddHeader(
+                        name="X-Special-Header",
+                        value="aws"
+                    ),
+                    actions.S3(
+                        bucket=bucket,
+                        object_key_prefix="emails/",
+                        topic=topic
+                    )
+                ]
+            ), ses.ReceiptRuleOptions(
+                recipients=["aws.com"],
+                actions=[
+                    actions.Sns(
+                        topic=topic
+                    )
+                ]
+            )
+            ]
+        )
+    '''
 
     def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
         '''
@@ -56,7 +93,7 @@ class AddHeader(
         '''
         props = AddHeaderProps(name=name, value=value)
 
-        jsii.create(AddHeader, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -81,6 +118,42 @@ class AddHeaderProps:
 
         :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
         :param value: The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\\r" or "\\n").
+
+        :exampleMetadata: infused
+
+        Example::
+
+            import aws_cdk.aws_s3 as s3
+            import aws_cdk.aws_ses_actions as actions
+            
+            
+            bucket = s3.Bucket(self, "Bucket")
+            topic = sns.Topic(self, "Topic")
+            
+            ses.ReceiptRuleSet(self, "RuleSet",
+                rules=[ses.ReceiptRuleOptions(
+                    recipients=["hello@aws.com"],
+                    actions=[
+                        actions.AddHeader(
+                            name="X-Special-Header",
+                            value="aws"
+                        ),
+                        actions.S3(
+                            bucket=bucket,
+                            object_key_prefix="emails/",
+                            topic=topic
+                        )
+                    ]
+                ), ses.ReceiptRuleOptions(
+                    recipients=["aws.com"],
+                    actions=[
+                        actions.Sns(
+                            topic=topic
+                        )
+                    ]
+                )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
@@ -124,7 +197,28 @@ class AddHeaderProps:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce"):
-    '''Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.'''
+    '''Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
+
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_ses_actions as ses_actions
+        import aws_cdk.aws_sns as sns
+        
+        # bounce_template: ses_actions.BounceTemplate
+        # topic: sns.Topic
+        
+        bounce = ses_actions.Bounce(
+            sender="sender",
+            template=bounce_template,
+        
+            # the properties below are optional
+            topic=topic
+        )
+    '''
 
     def __init__(
         self,
@@ -140,7 +234,7 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce
         '''
         props = BounceProps(sender=sender, template=template, topic=topic)
 
-        jsii.create(Bounce, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -172,6 +266,26 @@ class BounceProps:
         :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
         :param template: The template containing the message, reply code and status code.
         :param topic: The SNS topic to notify when the bounce action is taken. Default: no notification
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_ses_actions as ses_actions
+            import aws_cdk.aws_sns as sns
+            
+            # bounce_template: ses_actions.BounceTemplate
+            # topic: sns.Topic
+            
+            bounce_props = ses_actions.BounceProps(
+                sender="sender",
+                template=bounce_template,
+            
+                # the properties below are optional
+                topic=topic
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "sender": sender,
@@ -223,7 +337,18 @@ class BounceTemplate(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-ses-actions.BounceTemplate",
 ):
-    '''A bounce template.'''
+    '''A bounce template.
+
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_ses_actions as ses_actions
+        
+        bounce_template = ses_actions.BounceTemplate.MAILBOX_DOES_NOT_EXIST
+    '''
 
     def __init__(
         self,
@@ -241,7 +366,7 @@ class BounceTemplate(
             message=message, smtp_reply_code=smtp_reply_code, status_code=status_code
         )
 
-        jsii.create(BounceTemplate, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="MAILBOX_DOES_NOT_EXIST")
@@ -296,6 +421,22 @@ class BounceTemplateProps:
         :param message: Human-readable text to include in the bounce message.
         :param smtp_reply_code: The SMTP reply code, as defined by RFC 5321.
         :param status_code: The SMTP enhanced status code, as defined by RFC 3463.
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_ses_actions as ses_actions
+            
+            bounce_template_props = ses_actions.BounceTemplateProps(
+                message="message",
+                smtp_reply_code="smtpReplyCode",
+            
+                # the properties below are optional
+                status_code="statusCode"
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "message": message,
@@ -354,7 +495,29 @@ class EmailEncoding(enum.Enum):
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda"):
-    '''Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.'''
+    '''Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
+
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_lambda as lambda_
+        import aws_cdk.aws_ses_actions as ses_actions
+        import aws_cdk.aws_sns as sns
+        
+        # function_: lambda.Function
+        # topic: sns.Topic
+        
+        lambda_ = ses_actions.Lambda(
+            function=function_,
+        
+            # the properties below are optional
+            invocation_type=ses_actions.LambdaInvocationType.EVENT,
+            topic=topic
+        )
+    '''
 
     def __init__(
         self,
@@ -372,7 +535,7 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
             function=function, invocation_type=invocation_type, topic=topic
         )
 
-        jsii.create(Lambda, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -423,6 +586,27 @@ class LambdaProps:
         :param function: The Lambda function to invoke.
         :param invocation_type: The invocation type of the Lambda function. Default: Event
         :param topic: The SNS topic to notify when the Lambda action is taken. Default: no notification
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_lambda as lambda_
+            import aws_cdk.aws_ses_actions as ses_actions
+            import aws_cdk.aws_sns as sns
+            
+            # function_: lambda.Function
+            # topic: sns.Topic
+            
+            lambda_props = ses_actions.LambdaProps(
+                function=function_,
+            
+                # the properties below are optional
+                invocation_type=ses_actions.LambdaInvocationType.EVENT,
+                topic=topic
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "function": function,
@@ -471,7 +655,44 @@ class LambdaProps:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
-    '''Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.'''
+    '''Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.
+
+    :exampleMetadata: infused
+
+    Example::
+
+        import aws_cdk.aws_s3 as s3
+        import aws_cdk.aws_ses_actions as actions
+        
+        
+        bucket = s3.Bucket(self, "Bucket")
+        topic = sns.Topic(self, "Topic")
+        
+        ses.ReceiptRuleSet(self, "RuleSet",
+            rules=[ses.ReceiptRuleOptions(
+                recipients=["hello@aws.com"],
+                actions=[
+                    actions.AddHeader(
+                        name="X-Special-Header",
+                        value="aws"
+                    ),
+                    actions.S3(
+                        bucket=bucket,
+                        object_key_prefix="emails/",
+                        topic=topic
+                    )
+                ]
+            ), ses.ReceiptRuleOptions(
+                recipients=["aws.com"],
+                actions=[
+                    actions.Sns(
+                        topic=topic
+                    )
+                ]
+            )
+            ]
+        )
+    '''
 
     def __init__(
         self,
@@ -494,7 +715,7 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
             topic=topic,
         )
 
-        jsii.create(S3, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -533,6 +754,42 @@ class S3Props:
         :param kms_key: The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
         :param object_key_prefix: The key prefix of the S3 bucket. Default: no prefix
         :param topic: The SNS topic to notify when the S3 action is taken. Default: no notification
+
+        :exampleMetadata: infused
+
+        Example::
+
+            import aws_cdk.aws_s3 as s3
+            import aws_cdk.aws_ses_actions as actions
+            
+            
+            bucket = s3.Bucket(self, "Bucket")
+            topic = sns.Topic(self, "Topic")
+            
+            ses.ReceiptRuleSet(self, "RuleSet",
+                rules=[ses.ReceiptRuleOptions(
+                    recipients=["hello@aws.com"],
+                    actions=[
+                        actions.AddHeader(
+                            name="X-Special-Header",
+                            value="aws"
+                        ),
+                        actions.S3(
+                            bucket=bucket,
+                            object_key_prefix="emails/",
+                            topic=topic
+                        )
+                    ]
+                ), ses.ReceiptRuleOptions(
+                    recipients=["aws.com"],
+                    actions=[
+                        actions.Sns(
+                            topic=topic
+                        )
+                    ]
+                )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "bucket": bucket,
@@ -592,7 +849,44 @@ class S3Props:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
-    '''Publishes the email content within a notification to Amazon SNS.'''
+    '''Publishes the email content within a notification to Amazon SNS.
+
+    :exampleMetadata: infused
+
+    Example::
+
+        import aws_cdk.aws_s3 as s3
+        import aws_cdk.aws_ses_actions as actions
+        
+        
+        bucket = s3.Bucket(self, "Bucket")
+        topic = sns.Topic(self, "Topic")
+        
+        ses.ReceiptRuleSet(self, "RuleSet",
+            rules=[ses.ReceiptRuleOptions(
+                recipients=["hello@aws.com"],
+                actions=[
+                    actions.AddHeader(
+                        name="X-Special-Header",
+                        value="aws"
+                    ),
+                    actions.S3(
+                        bucket=bucket,
+                        object_key_prefix="emails/",
+                        topic=topic
+                    )
+                ]
+            ), ses.ReceiptRuleOptions(
+                recipients=["aws.com"],
+                actions=[
+                    actions.Sns(
+                        topic=topic
+                    )
+                ]
+            )
+            ]
+        )
+    '''
 
     def __init__(
         self,
@@ -606,7 +900,7 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
         '''
         props = SnsProps(topic=topic, encoding=encoding)
 
-        jsii.create(Sns, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -636,6 +930,42 @@ class SnsProps:
 
         :param topic: The SNS topic to notify.
         :param encoding: The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
+
+        :exampleMetadata: infused
+
+        Example::
+
+            import aws_cdk.aws_s3 as s3
+            import aws_cdk.aws_ses_actions as actions
+            
+            
+            bucket = s3.Bucket(self, "Bucket")
+            topic = sns.Topic(self, "Topic")
+            
+            ses.ReceiptRuleSet(self, "RuleSet",
+                rules=[ses.ReceiptRuleOptions(
+                    recipients=["hello@aws.com"],
+                    actions=[
+                        actions.AddHeader(
+                            name="X-Special-Header",
+                            value="aws"
+                        ),
+                        actions.S3(
+                            bucket=bucket,
+                            object_key_prefix="emails/",
+                            topic=topic
+                        )
+                    ]
+                ), ses.ReceiptRuleOptions(
+                    recipients=["aws.com"],
+                    actions=[
+                        actions.Sns(
+                            topic=topic
+                        )
+                    ]
+                )
+                ]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "topic": topic,
@@ -673,7 +1003,23 @@ class SnsProps:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
-    '''Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.'''
+    '''Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
+
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_ses_actions as ses_actions
+        import aws_cdk.aws_sns as sns
+        
+        # topic: sns.Topic
+        
+        stop = ses_actions.Stop(
+            topic=topic
+        )
+    '''
 
     def __init__(
         self,
@@ -685,7 +1031,7 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
         '''
         props = StopProps(topic=topic)
 
-        jsii.create(Stop, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -713,6 +1059,21 @@ class StopProps:
         '''Construction properties for a stop action.
 
         :param topic: The SNS topic to notify when the stop action is taken.
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_ses_actions as ses_actions
+            import aws_cdk.aws_sns as sns
+            
+            # topic: sns.Topic
+            
+            stop_props = ses_actions.StopProps(
+                topic=topic
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if topic is not None:
